@@ -129,9 +129,10 @@ class Response(client.Response):
 
     def __init__(self, model, response=None, url=None, **kwargs):
         # implement proxy mixin
-        if model._model_name in ProxyClient._proxies:
-            proxy = ProxyClient._proxies[model._model_name].__class__
-            extend(self, proxy)
+        model_name = model._model_name.lower()
+        if model_name in ProxyClient._proxies:
+            proxy = ProxyClient._proxies[model_name].__class__
+            extend(self, proxy, proxy.__dict__.copy())
             self.__init_proxy__()
 
         super(Response, self).__init__(model, response, url, **kwargs)
@@ -149,10 +150,10 @@ class Response(client.Response):
         Overrides to support api namespace and to_one class diversity.
         """
         try:
-            if not name in self._response:
+            if name not in self._response:
                 raise AttributeError(name)
 
-            elif not 'related_type' in self._schema['fields'][name]:
+            elif 'related_type' not in self._schema['fields'][name]:
                 return self.__getitem__(name)
 
         except AttributeError, e:
@@ -179,6 +180,8 @@ class Response(client.Response):
                         schema_uri = self._response[name]
                         schema_uri = schema_uri[0] if (
                             isinstance(schema_uri, list)) else schema_uri
+                        schema_uri = schema_uri['resource_uri'] if (
+                            isinstance(schema_uri, dict)) else schema_uri
 
                         logger.debug('trying to guess schema info from '
                                      'schema_uri (%s).' % schema_uri)
@@ -223,11 +226,12 @@ class Response(client.Response):
             setattr(self.model, resource_name, getattr(self.model, name))
 
         if schema['related_type'] == 'to_many':
+            resource_uris = [resource_uri['resource_uri'] if isinstance(resource_uri, dict) else resource_uri for resource_uri in self._response[name]]
             return ManyToManyManager(
                        model=model,
                        instance=self.model,
                        field_name=name,
-                       query={'id__in': [client.parse_id(resource_uri) for resource_uri in self._response[name]]})
+                       query={'id__in': [client.parse_id(resource_uri) for resource_uri in resource_uris]})
 
         elif schema['related_type'] == 'to_one':
             return Response(model=model, url=self._response[name])
@@ -327,13 +331,13 @@ class ProxyClient(client.Client):
     def __new__(cls, url, **kwargs):
         key = ProxyClient.build_client_key(url, **kwargs)
 
-        if not key in cls._clients:
+        if key not in cls._clients:
             cls._clients[key] = super(ProxyClient,
                                       cls).__new__(cls)
 
         proxy = kwargs.get('proxy')
         if proxy:
-            cls._proxies[proxy.__class__.__name__.lower().replace('proxy', '')] = proxy
+            cls._proxies[proxy.__class__.__name__.replace('Proxy', '').lower()] = proxy
 
         return cls._clients[key]
 
@@ -458,7 +462,7 @@ class ProxyClient(client.Client):
         else:
             url = self._url_gen('%s/schema/' % model_name)
 
-        if not model_name in ProxyClient._schemas:
+        if model_name not in ProxyClient._schemas:
             try:
                 self._schema_store[model_name] = self.request(url)
                 ProxyClient._schemas[model_name] = self._schema_store[model_name]
@@ -600,11 +604,11 @@ class ProxyMeta(type):
 
         declarative = Response not in bases
 
-        if declarative and name.lower() in ProxyClient._proxies:
+        if declarative and name in ProxyClient._proxies:
             # returns existing proxy object
-            return ProxyClient._proxies[name.lower()]
+            return ProxyClient._proxies[name]
 
-        meta = attrs.pop('Meta', None)
+        meta = attrs.pop('Meta', attrs.pop('_meta', None))
         abstract = getattr(meta, 'abstract', False)
 
         # create new proxy class
